emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-29 5f923ff1a6a: ; Fix typos


From: Stefan Kangas
Subject: emacs-29 5f923ff1a6a: ; Fix typos
Date: Sun, 3 Dec 2023 17:32:12 -0500 (EST)

branch: emacs-29
commit 5f923ff1a6a8a9ff6f06dc49c8e0e2ceee111567
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>

    ; Fix typos
---
 doc/lispintro/emacs-lisp-intro.texi    |  2 +-
 doc/lispref/keymaps.texi               |  2 +-
 doc/misc/calc.texi                     |  2 +-
 doc/misc/eglot.texi                    |  2 +-
 doc/misc/epa.texi                      |  4 ++--
 doc/misc/modus-themes.org              | 10 +++++-----
 doc/misc/tramp.texi                    |  2 +-
 doc/misc/widget.texi                   |  6 +++---
 etc/ERC-NEWS                           |  2 +-
 etc/ORG-NEWS                           |  2 +-
 etc/PROBLEMS                           |  2 +-
 lisp/cedet/semantic/complete.el        |  2 +-
 lisp/cedet/srecode/extract.el          |  2 +-
 lisp/cedet/srecode/srt-mode.el         |  2 +-
 lisp/desktop.el                        |  2 +-
 lisp/emacs-lisp/comp-cstr.el           |  2 +-
 lisp/emacs-lisp/comp.el                |  2 +-
 lisp/emacs-lisp/ert.el                 |  2 +-
 lisp/emacs-lisp/lisp.el                |  2 +-
 lisp/emacs-lisp/package-vc.el          |  2 +-
 lisp/erc/erc-services.el               |  2 +-
 lisp/gnus/gnus-search.el               |  2 +-
 lisp/gnus/nndiary.el                   |  2 +-
 lisp/gnus/nnml.el                      |  2 +-
 lisp/language/hanja-util.el            |  2 +-
 lisp/loadup.el                         |  2 +-
 lisp/mail/rmailout.el                  |  2 +-
 lisp/net/newst-treeview.el             |  2 +-
 lisp/net/sieve-manage.el               |  2 +-
 lisp/net/soap-client.el                |  2 +-
 lisp/net/tramp-sh.el                   |  6 +++---
 lisp/net/tramp.el                      |  2 +-
 lisp/org/oc-biblatex.el                |  2 +-
 lisp/org/oc.el                         |  2 +-
 lisp/org/org-capture.el                |  2 +-
 lisp/org/org-compat.el                 |  2 +-
 lisp/org/org-element.el                |  2 +-
 lisp/org/org-persist.el                |  4 ++--
 lisp/org/org-table.el                  |  2 +-
 lisp/org/org.el                        |  4 ++--
 lisp/progmodes/c-ts-common.el          |  4 ++--
 lisp/progmodes/c-ts-mode.el            |  2 +-
 lisp/progmodes/compile.el              |  2 +-
 lisp/progmodes/cperl-mode.el           |  2 +-
 lisp/progmodes/perl-mode.el            |  4 ++--
 lisp/progmodes/ruby-ts-mode.el         |  2 +-
 lisp/ses.el                            |  2 +-
 lisp/simple.el                         |  2 +-
 lisp/vc/vc-rcs.el                      |  2 +-
 lisp/vc/vc.el                          |  2 +-
 src/conf_post.h                        |  2 +-
 src/fileio.c                           |  2 +-
 src/image.c                            |  2 +-
 src/itree.c                            |  2 +-
 src/tparam.c                           |  2 +-
 src/window.c                           |  2 +-
 src/xfont.c                            |  2 +-
 src/xterm.c                            |  2 +-
 test/lisp/international/mule-tests.el  |  2 +-
 test/lisp/progmodes/perl-mode-tests.el |  2 +-
 60 files changed, 73 insertions(+), 73 deletions(-)

diff --git a/doc/lispintro/emacs-lisp-intro.texi 
b/doc/lispintro/emacs-lisp-intro.texi
index d6627a2a1ca..eb8ff413b79 100644
--- a/doc/lispintro/emacs-lisp-intro.texi
+++ b/doc/lispintro/emacs-lisp-intro.texi
@@ -14630,7 +14630,7 @@ almost the same code as for the recursive version of
 
 @need 800
 @noindent
-Let's re-use @kbd{C-c =} as a convenient key binding:
+Let's reuse @kbd{C-c =} as a convenient key binding:
 
 @smallexample
 (global-set-key "\C-c=" 'count-words-defun)
diff --git a/doc/lispref/keymaps.texi b/doc/lispref/keymaps.texi
index be924b5655a..c0d5905102d 100644
--- a/doc/lispref/keymaps.texi
+++ b/doc/lispref/keymaps.texi
@@ -491,7 +491,7 @@ useful if there is a command which doesn't exist in the map 
being
 defined, but which should have the @code{repeat-map} property.
 
 If the @code{:exit} list is empty then no commands in the map exit
-@code{repeat-mode}.  Specifying one ore more commands in this list is
+@code{repeat-mode}.  Specifying one or more commands in this list is
 useful if the keymap being defined contains a command that should not
 have the @code{repeat-map} property.
 @end table
diff --git a/doc/misc/calc.texi b/doc/misc/calc.texi
index de014bf0344..33d1f4160ff 100644
--- a/doc/misc/calc.texi
+++ b/doc/misc/calc.texi
@@ -11953,7 +11953,7 @@ trail pointer in various ways.
 @cindex Retrieving previous results
 The @kbd{t y} (@code{calc-trail-yank}) command reads the selected value in
 the trail and pushes it onto the Calculator stack.  It allows you to
-re-use any previously computed value without retyping.  With a numeric
+reuse any previously computed value without retyping.  With a numeric
 prefix argument @var{n}, it yanks the value @var{n} lines above the current
 trail pointer.
 
diff --git a/doc/misc/eglot.texi b/doc/misc/eglot.texi
index e1074bf9f0e..f7543193f18 100644
--- a/doc/misc/eglot.texi
+++ b/doc/misc/eglot.texi
@@ -1210,7 +1210,7 @@ in @ref{Project-specific configuration}.  Here is an 
example:
 @end lisp
 
 Note that the global value of @code{eglot-workspace-configuration} is
-always overriden if a directory-local value is detected.
+always overridden if a directory-local value is detected.
 
 @node JSONRPC objects in Elisp
 @section JSONRPC objects in Elisp
diff --git a/doc/misc/epa.texi b/doc/misc/epa.texi
index 917fd588593..3d00bc111c0 100644
--- a/doc/misc/epa.texi
+++ b/doc/misc/epa.texi
@@ -456,9 +456,9 @@ public key, it does not prompt for a passphrase for the 
buffer save,
 but it will prompt for your passphrase for file reads every now and
 then, depending on the GnuPG Agent cache configuration.
 
-@cindex tempory files created by easypg assistant
+@cindex temporary files created by easypg assistant
 To encrypt and decrypt files as described above EasyPG Assistant under
-certain circumstances uses intermediate tempory files that contain the
+certain circumstances uses intermediate temporary files that contain the
 plain-text contents of the files it processes.  EasyPG Assistant
 creates them below the directory returned by function
 @code{temporary-file-directory} (@pxref{Unique File Names, ,
diff --git a/doc/misc/modus-themes.org b/doc/misc/modus-themes.org
index 8cfa22df923..db7655e692c 100644
--- a/doc/misc/modus-themes.org
+++ b/doc/misc/modus-themes.org
@@ -4015,7 +4015,7 @@ height of the mode lines, but also remove their border:
 #+end_src
 
 The above relies on the ~set-face-attribute~ function, though users who
-plan to re-use colors from the theme and do so at scale are better off
+plan to reuse colors from the theme and do so at scale are better off
 with the more streamlined combination of the ~modus-themes-with-colors~
 macro and ~custom-set-faces~.
 
@@ -4023,7 +4023,7 @@ macro and ~custom-set-faces~.
 
 As explained before in this document, this approach has a syntax that is
 consistent with the source code of the themes, so it probably is easier
-to re-use parts of the design.
+to reuse parts of the design.
 
 The following emulates the stock Emacs style, while still using the
 colors of the Modus themes (whichever attribute is not explicitly stated
@@ -5076,7 +5076,7 @@ advanced customization options of the themes.
 [[#h:f4651d55-8c07-46aa-b52b-bed1e53463bb][Advanced customization]].
 
 In the following example, we are assuming that the user wants to (i)
-re-use color variables provided by the themes, (ii) be able to retain
+reuse color variables provided by the themes, (ii) be able to retain
 their tweaks while switching between ~modus-operandi~ and ~modus-vivendi~,
 and (iii) have the option to highlight either the foreground of the
 parentheses or the background as well.
@@ -5096,7 +5096,7 @@ Then we can update our preference with this:
 (setq my-highlight-parentheses-use-background nil)
 #+end_src
 
-To re-use colors from the themes, we must wrap our code in the
+To reuse colors from the themes, we must wrap our code in the
 ~modus-themes-with-colors~ macro.  Our implementation must interface with
 the variables ~highlight-parentheses-background-colors~ and/or
 ~highlight-parentheses-colors~.
@@ -5770,7 +5770,7 @@ more effective than trying to do the same with either red 
or blue (the
 latter is the least effective in that regard).
 
 When we need to work with several colors, it is always better to have
-sufficient manoeuvring space, especially since we cannot pick arbitrary
+sufficient maneuvering space, especially since we cannot pick arbitrary
 colors but only those that satisfy the accessibility objectives of the
 themes.
 
diff --git a/doc/misc/tramp.texi b/doc/misc/tramp.texi
index a4583a6074e..b604062c6c1 100644
--- a/doc/misc/tramp.texi
+++ b/doc/misc/tramp.texi
@@ -3619,7 +3619,7 @@ ssh@value{postfixhop}you@@remotehost@value{postfix}/path 
@key{RET}}
 Each involved method must be an inline method (@pxref{Inline methods}).
 
 @value{tramp} adds the ad-hoc definitions on the fly to
-@code{tramp-default-proxies-alist} and is available for re-use during
+@code{tramp-default-proxies-alist} and is available for reuse during
 that Emacs session.  Subsequent @value{tramp} connections to the same
 remote host can then use the shortcut form:
 @samp{@trampfn{ssh,you@@remotehost,/path}}.
diff --git a/doc/misc/widget.texi b/doc/misc/widget.texi
index eb411f29c5c..e8b41315000 100644
--- a/doc/misc/widget.texi
+++ b/doc/misc/widget.texi
@@ -1703,7 +1703,7 @@ A variable that holds the history of field minibuffer 
edits.
 
 @item :prompt-value
 A function that uses the @code{:prompt-internal} function and the
-@code{:prompt-history} value to prompt for a string, and retun the
+@code{:prompt-history} value to prompt for a string, and return the
 user response in the external format.
 
 @item :action
@@ -1714,7 +1714,7 @@ Function that takes care of creating the widget, 
respecting its
 @code{:size} and @code{:value}.
 
 @item :value-set
-Function to use to modify programatically the current value of the
+Function to use to modify programmatically the current value of the
 widget.
 
 @item :value-delete
@@ -2455,7 +2455,7 @@ difference from the @code{const} widget is that they will 
allow the
 user to see the variable or function documentation for the symbol.
 
 This is accomplished via using the @samp{%h} format escape, and adding
-an appropiate @code{:documentation-property} function for each widget.
+an appropriate @code{:documentation-property} function for each widget.
 
 @deffn Widget variable-item
 An immutable symbol that is bound as a variable.
diff --git a/etc/ERC-NEWS b/etc/ERC-NEWS
index 9672a86345b..fb72b0834ac 100644
--- a/etc/ERC-NEWS
+++ b/etc/ERC-NEWS
@@ -1195,7 +1195,7 @@ Only the macros in cl-macs.el are used.
 
 ** Make flood protection toggle-able as on/off, removing the 'strict option.
 
-** If possible, re-use channel buffers when reconnecting to a server.
+** If possible, reuse channel buffers when reconnecting to a server.
 
 ** Text in ERC buffers is now read-only by default.
 To get the previous behavior,
diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index 5f92c056018..1e87f10748f 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -1098,7 +1098,7 @@ Conversion to SVG exposes a number of additional 
customizations that
 give the user full control over the contents of the latex source
 block. ~org-babel-latex-preamble~, ~org-babel-latex-begin-env~ and
 ~org-babel-latex-end-env~ are new customization options added to allow
-the user to specify the preamble and code that preceedes and proceeds
+the user to specify the preamble and code that precedes and proceeds
 the contents of the source block.
 
 *** New option ~org-html-meta-tags~ allows for HTML meta tags customization
diff --git a/etc/PROBLEMS b/etc/PROBLEMS
index 71cade6343c..f290b86cb8a 100644
--- a/etc/PROBLEMS
+++ b/etc/PROBLEMS
@@ -1994,7 +1994,7 @@ remote X server, try this:
 
 *** Dropping text on xterm doesn't work.
 
-Emacs sends sythetic button events to legacy clients such as xterm
+Emacs sends synthetic button events to legacy clients such as xterm
 that do not support either the XDND or Motif drag-and-drop protocols
 in order to "paste" the text that was dropped.  Unfortunately, xterm
 is configured to ignore these events by default.  Add the following to
diff --git a/lisp/cedet/semantic/complete.el b/lisp/cedet/semantic/complete.el
index 6f84b83ab75..b6ad9b598df 100644
--- a/lisp/cedet/semantic/complete.el
+++ b/lisp/cedet/semantic/complete.el
@@ -1046,7 +1046,7 @@ Output must be in semanticdb Find result format."
                     (and last-prefix (string-prefix-p last-prefix prefix t)))
                 ;; We have the same prefix, or last-prefix is a
                 ;; substring of the of new prefix, in which case we are
-                ;; refining our symbol so just re-use cache.
+                ;; refining our symbol so just reuse cache.
                 (oref obj last-all-completions))
                ((and last-prefix
                      (> (length prefix) 1)
diff --git a/lisp/cedet/srecode/extract.el b/lisp/cedet/srecode/extract.el
index 4eb7632b721..7e74746f1da 100644
--- a/lisp/cedet/srecode/extract.el
+++ b/lisp/cedet/srecode/extract.el
@@ -33,7 +33,7 @@
 ;; or deep template calls can be extracted.
 ;;
 ;; This code was specifically written for srecode-document, which
-;; wants to extract user written text, and re-use it in a reformatted
+;; wants to extract user written text, and reuse it in a reformatted
 ;; comment.
 
 (require 'srecode)
diff --git a/lisp/cedet/srecode/srt-mode.el b/lisp/cedet/srecode/srt-mode.el
index 6bd416c5690..30509298ddc 100644
--- a/lisp/cedet/srecode/srt-mode.el
+++ b/lisp/cedet/srecode/srt-mode.el
@@ -420,7 +420,7 @@ Moves to the end of one named section."
              (when (string= (car (car subdicts)) name)
                (setq res (cdr (car subdicts))))
              (setq subdicts (cdr subdicts)))
-           ;; Pre-pend our global vars.
+           ;; Prepend our global vars.
            (append global res))
        ;; If we aren't in a subsection, just do the global variables
        global
diff --git a/lisp/desktop.el b/lisp/desktop.el
index d6d3e609b21..9894b73bd6a 100644
--- a/lisp/desktop.el
+++ b/lisp/desktop.el
@@ -293,7 +293,7 @@ May be used to show a dired buffer."
   :version "22.1")
 
 (defcustom desktop-not-loaded-hook nil
-  "Normal hook run when the user declines to re-use a desktop file.
+  "Normal hook run when the user declines to reuse a desktop file.
 Run in the directory in which the desktop file was found.
 May be used to deal with accidental multiple Emacs jobs."
   :type 'hook
diff --git a/lisp/emacs-lisp/comp-cstr.el b/lisp/emacs-lisp/comp-cstr.el
index 787232067a1..4653e1f991c 100644
--- a/lisp/emacs-lisp/comp-cstr.el
+++ b/lisp/emacs-lisp/comp-cstr.el
@@ -690,7 +690,7 @@ DST is returned."
             (cl-loop
              for val in (valset src)
              ;; If (member value) is subtypep of all other sources then
-             ;; is good to be colleted.
+             ;; is good to be collected.
              when (cl-every (lambda (s)
                               (or (memql val (valset s))
                                   (cl-some (lambda (type)
diff --git a/lisp/emacs-lisp/comp.el b/lisp/emacs-lisp/comp.el
index b5355acf7cc..586a4df3890 100644
--- a/lisp/emacs-lisp/comp.el
+++ b/lisp/emacs-lisp/comp.el
@@ -4322,7 +4322,7 @@ last directory in `native-comp-eln-load-path')."
 Make sure that eln file is younger than byte-compiled one and
 return the filename of this last.
 
-This function can be used only in conjuntion with
+This function can be used only in conjunction with
 `byte+native-compile' `byte-to-native-output-buffer-file' (see
 `batch-byte+native-compile')."
   (pcase byte-to-native-output-buffer-file
diff --git a/lisp/emacs-lisp/ert.el b/lisp/emacs-lisp/ert.el
index 5d001307125..74c59953db6 100644
--- a/lisp/emacs-lisp/ert.el
+++ b/lisp/emacs-lisp/ert.el
@@ -98,7 +98,7 @@ Even modest settings for `print-length' and `print-level' can
 produce extremely long lines in backtraces and lengthy delays in
 forming them.  This variable governs the target maximum line
 length by manipulating these two variables while printing stack
-traces.  Setting this variable to t will re-use the value of
+traces.  Setting this variable to t will reuse the value of
 `backtrace-line-length' while printing stack traces in ERT batch
 mode.  Any other value will be temporarily bound to
 `backtrace-line-length' when producing stack traces in batch
diff --git a/lisp/emacs-lisp/lisp.el b/lisp/emacs-lisp/lisp.el
index 17d58b1e3c6..0bd1cc8b2e0 100644
--- a/lisp/emacs-lisp/lisp.el
+++ b/lisp/emacs-lisp/lisp.el
@@ -93,7 +93,7 @@ report errors as appropriate for this kind of usage."
 
 (defun mark-sexp (&optional arg allow-extend)
   "Set mark ARG sexps from point or move mark one sexp.
-When called from Lisp with ALLOW-EXTEND ommitted or nil, mark is
+When called from Lisp with ALLOW-EXTEND omitted or nil, mark is
 set ARG sexps from point.
 With ARG and ALLOW-EXTEND both non-nil (interactively, with prefix
 argument), the place to which mark goes is the same place \\[forward-sexp]
diff --git a/lisp/emacs-lisp/package-vc.el b/lisp/emacs-lisp/package-vc.el
index 2a5f14b3ee3..c6625bf0ff8 100644
--- a/lisp/emacs-lisp/package-vc.el
+++ b/lisp/emacs-lisp/package-vc.el
@@ -29,7 +29,7 @@
 ;; To install a package from source use `package-vc-install'.  If you
 ;; aren't interested in activating a package, you can use
 ;; `package-vc-checkout' instead, which will prompt you for a target
-;; directory.  If you wish to re-use an existing checkout, the command
+;; directory.  If you wish to reuse an existing checkout, the command
 ;; `package-vc-install-from-checkout' will create a symbolic link and
 ;; prepare the package.
 ;;
diff --git a/lisp/erc/erc-services.el b/lisp/erc/erc-services.el
index 2e6959cc3f0..270cd1bdd4c 100644
--- a/lisp/erc/erc-services.el
+++ b/lisp/erc/erc-services.el
@@ -168,7 +168,7 @@ You can also use \\[erc-nickserv-identify-mode] to change 
modes."
   :type 'boolean)
 
 (defcustom erc-use-auth-source-for-nickserv-password nil
-  "Query auth-source for a password when identifiying to NickServ.
+  "Query auth-source for a password when identifying to NickServ.
 Passwords from `erc-nickserv-passwords' take precedence.  See
 function `erc-nickserv-get-password'."
   :version "28.1"
diff --git a/lisp/gnus/gnus-search.el b/lisp/gnus/gnus-search.el
index 27c71fa6c6a..13265586e5f 100644
--- a/lisp/gnus/gnus-search.el
+++ b/lisp/gnus/gnus-search.el
@@ -1444,7 +1444,7 @@ Returns a list of [group article score] vectors."
        (when (and f-name
                    (file-readable-p f-name)
                   (null (file-directory-p f-name)))
-          ;; `expand-file-name' canoncalizes the file name,
+          ;; `expand-file-name' canonicalizes the file name,
           ;; specifically collapsing multiple consecutive directory
           ;; separators.
           (setq f-name (expand-file-name f-name)
diff --git a/lisp/gnus/nndiary.el b/lisp/gnus/nndiary.el
index c7a75105c08..95d2d52c342 100644
--- a/lisp/gnus/nndiary.el
+++ b/lisp/gnus/nndiary.el
@@ -1023,7 +1023,7 @@ all.  This may very well take some time.")
 (defun nndiary-generate-nov-databases (&optional server)
   "Generate NOV databases in all nndiary directories."
   (interactive (list (or (nnoo-current-server 'nndiary) "")))
-  ;; Read the active file to make sure we don't re-use articles
+  ;; Read the active file to make sure we don't reuse articles
   ;; numbers in empty groups.
   (nnmail-activate 'nndiary)
   (unless (nndiary-server-opened server)
diff --git a/lisp/gnus/nnml.el b/lisp/gnus/nnml.el
index d969716f020..44962c61b4b 100644
--- a/lisp/gnus/nnml.el
+++ b/lisp/gnus/nnml.el
@@ -830,7 +830,7 @@ article number.  This function is called narrowed to an 
article."
 (defun nnml-generate-nov-databases (&optional server)
   "Generate NOV databases in all nnml directories."
   (interactive (list (or (nnoo-current-server 'nnml) "")))
-  ;; Read the active file to make sure we don't re-use articles
+  ;; Read the active file to make sure we don't reuse articles
   ;; numbers in empty groups.
   (nnmail-activate 'nnml)
   (unless (nnml-server-opened server)
diff --git a/lisp/language/hanja-util.el b/lisp/language/hanja-util.el
index be0364b1c23..6334b63334c 100644
--- a/lisp/language/hanja-util.el
+++ b/lisp/language/hanja-util.el
@@ -6437,7 +6437,7 @@ character.  This variable is initialized by 
`hanja-init-load'.")
     (message "")))
 
 ;; List of current conversion status.
-;; The first element is the strating position of shown list.
+;; The first element is the starting position of shown list.
 ;; It is a group number each split by `hanja-list-width'.
 ;; The second element is the position of selected element.
 ;; The third element is a list of suitable Hanja candidate.
diff --git a/lisp/loadup.el b/lisp/loadup.el
index 1cc70348267..8f884108d9a 100644
--- a/lisp/loadup.el
+++ b/lisp/loadup.el
@@ -479,7 +479,7 @@ lost after dumping")))
 (defvar comp-subr-arities-h)
 (when (featurep 'native-compile)
   ;; Save the arity for all primitives so the compiler can always
-  ;; retrive it even in case of redefinition.
+  ;; retrieve it even in case of redefinition.
   (mapatoms (lambda (f)
               (when (subr-primitive-p (symbol-function f))
                 (puthash f (func-arity f) comp-subr-arities-h))))
diff --git a/lisp/mail/rmailout.el b/lisp/mail/rmailout.el
index d0c0efec53b..465526c59cd 100644
--- a/lisp/mail/rmailout.el
+++ b/lisp/mail/rmailout.el
@@ -454,7 +454,7 @@ display message number MSG."
       (narrow-to-region (point-max) (point-max)))
     (insert-buffer-substring tembuf)
     (rmail-count-new-messages t)
-    ;; FIXME should re-use existing windows.
+    ;; FIXME should reuse existing windows.
     (if (rmail-summary-exists)
        (rmail-select-summary (rmail-update-summary)))
     (rmail-show-message-1 msg)))
diff --git a/lisp/net/newst-treeview.el b/lisp/net/newst-treeview.el
index 39988ba6cfb..3b2714f3cc4 100644
--- a/lisp/net/newst-treeview.el
+++ b/lisp/net/newst-treeview.el
@@ -1466,7 +1466,7 @@ Move to next item unless DONT-PROCEED is non-nil."
       nil)))
 
 (defun newsticker--treeview-get-second-child (node)
-  "Get scond child of NODE."
+  "Get second child of NODE."
   (let ((children (widget-get node :children)))
     (if children
         (car (cdr children))
diff --git a/lisp/net/sieve-manage.el b/lisp/net/sieve-manage.el
index 4866f788bff..733b235bedf 100644
--- a/lisp/net/sieve-manage.el
+++ b/lisp/net/sieve-manage.el
@@ -171,7 +171,7 @@ Valid states are `closed', `initial', `nonauth', and 
`auth'.")
   "Append ARGS to `sieve-manage-log' buffer.
 
 ARGS can be a string or a list of strings.
-The buffer to use for logging is specifified via `sieve-manage-log'.
+The buffer to use for logging is specified via `sieve-manage-log'.
 If it is nil, logging is disabled.
 
 When the `sieve-manage-log' buffer doesn't exist, it gets created (and
diff --git a/lisp/net/soap-client.el b/lisp/net/soap-client.el
index 73974f864b3..badf24c74d9 100644
--- a/lisp/net/soap-client.el
+++ b/lisp/net/soap-client.el
@@ -1953,7 +1953,7 @@ This is a specialization of `soap-decode-type' for
                                   (xml-get-children node (intern e-name)))
                               ;; e-name is nil so a) we don't know which
                               ;; children to operate on, and b) we want to
-                              ;; re-use soap-decode-xs-complex-type, which
+                              ;; reuse soap-decode-xs-complex-type, which
                               ;; expects a node argument with a complex
                               ;; type; therefore we need to operate on the
                               ;; entire node.  We wrap node in a list so
diff --git a/lisp/net/tramp-sh.el b/lisp/net/tramp-sh.el
index aa1d025bf19..cf113b117ed 100644
--- a/lisp/net/tramp-sh.el
+++ b/lisp/net/tramp-sh.el
@@ -2498,7 +2498,7 @@ The method used must be an out-of-band method."
                      copy-program copy-args)))
                (tramp-message v 6 "%s" (string-join (process-command p) " "))
                (process-put p 'tramp-vector v)
-               ;; This is neded for ssh or PuTTY based processes, and
+               ;; This is needed for ssh or PuTTY based processes, and
                ;; only if the respective options are set.  Perhaps,
                ;; the setting could be more fine-grained.
                ;; (process-put p 'tramp-shared-socket t)
@@ -3840,7 +3840,7 @@ Fall back to normal file name handler if no Tramp handler 
exists."
           (string-join sequence " "))
        (tramp-message v 6 "Run `%s', %S" (string-join sequence " ") p)
        (process-put p 'tramp-vector v)
-       ;; This is neded for ssh or PuTTY based processes, and only if
+       ;; This is needed for ssh or PuTTY based processes, and only if
        ;; the respective options are set.  Perhaps, the setting could
        ;; be more fine-grained.
        ;; (process-put p 'tramp-shared-socket t)
@@ -5224,7 +5224,7 @@ connection if a previous connection has died for some 
reason."
                ;; Set sentinel and query flag.  Initialize variables.
                (set-process-sentinel p #'tramp-process-sentinel)
                (process-put p 'tramp-vector vec)
-               ;; This is neded for ssh or PuTTY based processes, and
+               ;; This is needed for ssh or PuTTY based processes, and
                ;; only if the respective options are set.  Perhaps,
                ;; the setting could be more fine-grained.
                ;; (process-put p 'tramp-shared-socket t)
diff --git a/lisp/net/tramp.el b/lisp/net/tramp.el
index 5e8d6bbcd08..70f8a45bdcc 100644
--- a/lisp/net/tramp.el
+++ b/lisp/net/tramp.el
@@ -5083,7 +5083,7 @@ substitution.  SPEC-LIST is a list of char/value pairs 
used for
            (when filter
              (set-process-filter p filter))
            (process-put p 'tramp-vector v)
-           ;; This is neded for ssh or PuTTY based processes, and
+           ;; This is needed for ssh or PuTTY based processes, and
            ;; only if the respective options are set.  Perhaps, the
            ;; setting could be more fine-grained.
            ;; (process-put p 'tramp-shared-socket t)
diff --git a/lisp/org/oc-biblatex.el b/lisp/org/oc-biblatex.el
index b2d31f0f635..0ed5459a66d 100644
--- a/lisp/org/oc-biblatex.el
+++ b/lisp/org/oc-biblatex.el
@@ -26,7 +26,7 @@
 
 ;; The processor relies on "biblatex" LaTeX package.  As such it ensures that
 ;; the package is properly required in the document's preamble.  More
-;; accurately, it will re-use any "\usepackage{biblatex}" already present in
+;; accurately, it will reuse any "\usepackage{biblatex}" already present in
 ;; the document (e.g., through `org-latex-packages-alist'), or insert one using
 ;; options defined in `org-cite-biblatex-options'.
 
diff --git a/lisp/org/oc.el b/lisp/org/oc.el
index 8a7b662098a..269f7fd13a1 100644
--- a/lisp/org/oc.el
+++ b/lisp/org/oc.el
@@ -52,7 +52,7 @@
 ;; through the "cite_export" keyword.
 
 ;; Eventually, this library provides some tools, mainly targeted at
-;; processor implementors.  Most are export-specific and are located
+;; processor implementers.  Most are export-specific and are located
 ;; in the "Tools only available during export" and "Tools generating
 ;; or operating on parsed data" sections.
 
diff --git a/lisp/org/org-capture.el b/lisp/org/org-capture.el
index a696c615b2a..41872ff87ef 100644
--- a/lisp/org/org-capture.el
+++ b/lisp/org/org-capture.el
@@ -1312,7 +1312,7 @@ may have been stored before."
                (while (< (point) end)
                  (indent-to i)
                  (forward-line)))
-             ;; Pre-pending an item could change the type of the list
+             ;; Prepending an item could change the type of the list
              ;; if there is a mismatch.  In this situation,
              ;; prioritize the existing list.
              (when prepend?
diff --git a/lisp/org/org-compat.el b/lisp/org/org-compat.el
index d5bf2191ae7..db5e9283bf5 100644
--- a/lisp/org/org-compat.el
+++ b/lisp/org/org-compat.el
@@ -141,7 +141,7 @@ Unibyte strings are converted to multibyte for comparison."
 Elements in COMPONENTS must be a string or nil.
 DIRECTORY or the non-final elements in COMPONENTS may or may not end
 with a slash -- if they don't end with a slash, a slash will be
-inserted before contatenating."
+inserted before concatenating."
     (save-match-data
       (mapconcat
        #'identity
diff --git a/lisp/org/org-element.el b/lisp/org/org-element.el
index 0debd1a6818..e6bff9120c4 100644
--- a/lisp/org/org-element.el
+++ b/lisp/org/org-element.el
@@ -5484,7 +5484,7 @@ This variable is used to determine when re-parsing buffer 
is not going
 to slow down the command.
 
 If the commands end up modifying the cache, the worst case scenario is
-performance drop.  So, advicing these commands is safe.  Yet, it is
+performance drop.  So, advising these commands is safe.  Yet, it is
 better to remove the commands advised in such a way from this list.")
 
 (defmacro org-element--request-key (request)
diff --git a/lisp/org/org-table.el b/lisp/org/org-table.el
index fd10ccf576f..eb4da2c3a72 100644
--- a/lisp/org/org-table.el
+++ b/lisp/org/org-table.el
@@ -4894,7 +4894,7 @@ This function sets up the following dynamically scoped 
variables:
                        (push (cons field v) org-table-local-parameters)
                        (push (list field line col)
                              org-table-named-field-locations))))))))))
-      ;; Re-use existing markers when possible.
+      ;; Reuse existing markers when possible.
       (if (markerp org-table-current-begin-pos)
          (move-marker org-table-current-begin-pos (point))
        (setq org-table-current-begin-pos (point-marker)))
diff --git a/lisp/org/org.el b/lisp/org/org.el
index 863a9e093f5..2f4cfe16866 100644
--- a/lisp/org/org.el
+++ b/lisp/org/org.el
@@ -1230,7 +1230,7 @@ This applies to indirect buffers created with the commands
 Valid values are:
 current-window   Display in the current window
 other-window     Just display in another window.
-dedicated-frame  Create one new frame, and re-use it each time.
+dedicated-frame  Create one new frame, and reuse it each time.
 new-frame        Make a new frame each time.  Note that in this case
                  previously-made indirect buffers are kept, and you need to
                  kill these buffers yourself."
@@ -4582,7 +4582,7 @@ is available.  This option applies only if FILE is a URL."
                            file)
                   nil))
             (error (if noerror
-                       (message "Org could't download \"%s\": %s %S" file (car 
error) (cdr error))
+                       (message "Org couldn't download \"%s\": %s %S" file 
(car error) (cdr error))
                      (signal (car error) (cdr error)))))
         (funcall (if noerror #'message #'user-error)
                  "The remote resource %S is considered unsafe, and will not be 
downloaded."
diff --git a/lisp/progmodes/c-ts-common.el b/lisp/progmodes/c-ts-common.el
index 3b0814970ad..eba13934ede 100644
--- a/lisp/progmodes/c-ts-common.el
+++ b/lisp/progmodes/c-ts-common.el
@@ -116,7 +116,7 @@ non-whitespace characters of the current line."
   "Regexp pattern that matches a comment in C-like languages.")
 
 (defun c-ts-common--fill-paragraph (&optional arg)
-  "Fillling function for `c-ts-common'.
+  "Filling function for `c-ts-common'.
 ARG is passed to `fill-paragraph'."
   (interactive "*P")
   (save-restriction
@@ -134,7 +134,7 @@ ARG is passed to `fill-paragraph'."
       t)))
 
 (defun c-ts-common--fill-block-comment (&optional arg)
-  "Fillling function for block comments.
+  "Filling function for block comments.
 ARG is passed to `fill-paragraph'.  Assume point is in a block
 comment."
   (let* ((node (treesit-node-at (point)))
diff --git a/lisp/progmodes/c-ts-mode.el b/lisp/progmodes/c-ts-mode.el
index 31a9d0fc886..21fb0ca9e53 100644
--- a/lisp/progmodes/c-ts-mode.el
+++ b/lisp/progmodes/c-ts-mode.el
@@ -1321,7 +1321,7 @@ recommended to enable `electric-pair-mode' with this 
mode."
                                                 c-ts-mode-indent-style)
       :help "Show the name of the C/C++ indentation style for current buffer"]
      ["Set Comment Style" c-ts-mode-toggle-comment-style
-      :help "Toglle C/C++ comment style between block and line comments"])
+      :help "Toggle C/C++ comment style between block and line comments"])
     "--"
     ("Toggle..."
      ["SubWord Mode" subword-mode
diff --git a/lisp/progmodes/compile.el b/lisp/progmodes/compile.el
index ccf64fb670b..b09a308c70a 100644
--- a/lisp/progmodes/compile.el
+++ b/lisp/progmodes/compile.el
@@ -1786,7 +1786,7 @@ to a function that generates a unique name."
 ;; run compile with the default command line
 (defun recompile (&optional edit-command)
   "Re-compile the program including the current buffer.
-If this is run in a Compilation mode buffer, re-use the arguments from the
+If this is run in a Compilation mode buffer, reuse the arguments from the
 original use.  Otherwise, recompile using `compile-command'.
 If the optional argument `edit-command' is non-nil, the command can be edited."
   (interactive "P")
diff --git a/lisp/progmodes/cperl-mode.el b/lisp/progmodes/cperl-mode.el
index 412283f3488..f67518185bd 100644
--- a/lisp/progmodes/cperl-mode.el
+++ b/lisp/progmodes/cperl-mode.el
@@ -1329,7 +1329,7 @@ Covers packages, subroutines, and POD headings.")
 
 (defun cperl-block-declaration-p ()
   "Test whether the following ?\\{ opens a declaration block.
-Returns the column where the declarating keyword is found, or nil
+Returns the column where the declaring keyword is found, or nil
 if this isn't a declaration block.  Declaration blocks are named
 subroutines, packages and the like.  They start with a keyword
 and a name, to be followed by various descriptive items which are
diff --git a/lisp/progmodes/perl-mode.el b/lisp/progmodes/perl-mode.el
index 9137119d052..c5d4df2ccfc 100644
--- a/lisp/progmodes/perl-mode.el
+++ b/lisp/progmodes/perl-mode.el
@@ -465,7 +465,7 @@
                      (scan-error (goto-char startpos) nil))
                  (not (or (nth 8 (parse-partial-sexp
                                   ;; Since we don't know if point is within
-                                  ;; the first or the scond arg, we have to
+                                  ;; the first or the second arg, we have to
                                   ;; start from the beginning.
                                   (if twoargs (1+ (nth 8 state)) (point))
                                   limit nil nil state 'syntax-table))
@@ -511,7 +511,7 @@
                                     (string-to-syntax "|e")
                                   (string-to-syntax "\"e")))
              (forward-char 1)
-             ;; Re-use perl-syntax-propertize-special-constructs to handle the
+             ;; Reuse perl-syntax-propertize-special-constructs to handle the
              ;; second part (the first delimiter of second part can't be
              ;; preceded by "s" or "tr" or "y", so it will not be considered
              ;; as twoarg).
diff --git a/lisp/progmodes/ruby-ts-mode.el b/lisp/progmodes/ruby-ts-mode.el
index 5b432c8098c..c146b80542e 100644
--- a/lisp/progmodes/ruby-ts-mode.el
+++ b/lisp/progmodes/ruby-ts-mode.el
@@ -601,7 +601,7 @@ a statement container is a node that matches
 
            ;; case expression: when, in_clause, and else are all
            ;; children of case.  when and in_clause have pattern and
-           ;; body as fields.  body has "then" and then the statemets.
+           ;; body as fields.  body has "then" and then the statements.
            ;; i.e. the statements are not children of when but then.
            ;; But for the statements are children of else.
            ((match "when" "case")
diff --git a/lisp/ses.el b/lisp/ses.el
index 30bf33e47bf..23018403cda 100644
--- a/lisp/ses.el
+++ b/lisp/ses.el
@@ -2245,7 +2245,7 @@ Based on the current set of columns and `window-hscroll' 
position."
 ;; Redisplay and recalculation
 ;;----------------------------------------------------------------------------
 (defun ses-jump-prefix (prefix-int)
-  "Convert an integer (unversal prefix) into a (ROW . COL).
+  "Convert an integer (universal prefix) into a (ROW . COL).
 Does it by numbering cells starting from 0 from top left to bottom right,
 going row by row."
   (and (>= prefix-int 0)
diff --git a/lisp/simple.el b/lisp/simple.el
index 9ef348f74dc..6453dfbcd2b 100644
--- a/lisp/simple.el
+++ b/lisp/simple.el
@@ -8705,7 +8705,7 @@ node `(elisp) Word Motion' for details."
 
 (defun mark-word (&optional arg allow-extend)
   "Set mark ARG words from point or move mark one word.
-When called from Lisp with ALLOW-EXTEND ommitted or nil, mark is
+When called from Lisp with ALLOW-EXTEND omitted or nil, mark is
 set ARG words from point.
 With ARG and ALLOW-EXTEND both non-nil (interactively, with prefix
 argument), the place to which mark goes is the same place \\[forward-word]
diff --git a/lisp/vc/vc-rcs.el b/lisp/vc/vc-rcs.el
index c2112b76ad3..e7b6776de33 100644
--- a/lisp/vc/vc-rcs.el
+++ b/lisp/vc/vc-rcs.el
@@ -714,7 +714,7 @@ Optional arg REVISION is a revision to annotate from."
             (insert insn)
           (delete-char insn)))
       ;; Now apply the forward-chronological edits (directly from the
-      ;; parse-tree) for the branch(es), if necessary.  We re-use vars
+      ;; parse-tree) for the branch(es), if necessary.  We reuse vars
       ;; `pre' and `meta' for the sake of internal func `r/d/a'.
       (while nbls
         (setq pre (cdr (pop nbls)))
diff --git a/lisp/vc/vc.el b/lisp/vc/vc.el
index 1dadceda8c4..c9a26250f1a 100644
--- a/lisp/vc/vc.el
+++ b/lisp/vc/vc.el
@@ -668,7 +668,7 @@
 ;;;; New Primitives:
 ;;
 ;; - uncommit: undo last checkin, leave changes in place in the workfile,
-;;   stash the commit comment for re-use.
+;;   stash the commit comment for reuse.
 ;;
 ;; - deal with push operations.
 ;;
diff --git a/src/conf_post.h b/src/conf_post.h
index 0d5f90a6910..1a8c35720f2 100644
--- a/src/conf_post.h
+++ b/src/conf_post.h
@@ -96,7 +96,7 @@ typedef bool bool_bf;
 #ifdef emacs
 /* We include stdlib.h here, because Gnulib's stdlib.h might redirect
    'free' to its replacement, and we want to avoid that in unexec
-   builds.  Inclduing it here will render its inclusion after config.h
+   builds.  Including it here will render its inclusion after config.h
    a no-op.  */
 # if (defined DARWIN_OS && defined HAVE_UNEXEC) || defined HYBRID_MALLOC
 #  include <stdlib.h>
diff --git a/src/fileio.c b/src/fileio.c
index 4d5365bff9a..4d3aea3554e 100644
--- a/src/fileio.c
+++ b/src/fileio.c
@@ -758,7 +758,7 @@ DEFUN ("file-name-concat", Ffile_name_concat, 
Sfile_name_concat, 1, MANY, 0,
 Elements in COMPONENTS must be a string or nil.
 DIRECTORY or the non-final elements in COMPONENTS may or may not end
 with a slash -- if they don't end with a slash, a slash will be
-inserted before contatenating.
+inserted before concatenating.
 usage: (record DIRECTORY &rest COMPONENTS) */)
   (ptrdiff_t nargs, Lisp_Object *args)
 {
diff --git a/src/image.c b/src/image.c
index c717ac88dca..e557f97377d 100644
--- a/src/image.c
+++ b/src/image.c
@@ -11424,7 +11424,7 @@ svg_load_image (struct frame *f, struct image *img, 
char *contents,
       }
 
 #if HAVE_NTGUI
-    /* Windows stores the image colours in BGR format, and SVG expects
+    /* Windows stores the image colors in BGR format, and SVG expects
        them in RGB.  */
     foreground = (foreground & 0x0000FF) << 16
       | (foreground & 0xFF0000) >> 16
diff --git a/src/itree.c b/src/itree.c
index b8db08bc74c..6e80c330c94 100644
--- a/src/itree.c
+++ b/src/itree.c
@@ -74,7 +74,7 @@ along with GNU Emacs.  If not, see 
<https://www.gnu.org/licenses/>.  */
 
    Consider the case where next-overlay-change is called at POS, all
    interval BEG positions are less than pos POS and all interval END
-   posistions are after.  These END positions have no order, and so
+   positions are after.  These END positions have no order, and so
    *every* interval must be examined.  This is at least O(N).  The
    previous-overlay-change case is similar.  The root issue is that
    the iterative "narrowing" approach is not guaranteed to reduce the
diff --git a/src/tparam.c b/src/tparam.c
index 1a5eab37452..d1db99e7417 100644
--- a/src/tparam.c
+++ b/src/tparam.c
@@ -184,7 +184,7 @@ tparam1 (const char *string, char *outstring, int len,
              argp++;
              break;
 
-           case 'b':           /* %b means back up one arg (and re-use it).  */
+           case 'b':           /* %b means back up one arg (and reuse it).  */
              argp--;
              break;
 
diff --git a/src/window.c b/src/window.c
index 1dc977626b3..a5d88e2ad87 100644
--- a/src/window.c
+++ b/src/window.c
@@ -526,7 +526,7 @@ select_window (Lisp_Object window, Lisp_Object norecord,
     /* Do not select a tooltip window (Bug#47207).  */
     error ("Cannot select a tooltip window");
 
-  /* We deinitely want to select WINDOW, not the mini-window.  */
+  /* We definitely want to select WINDOW, not the mini-window.  */
   f->select_mini_window_flag = false;
 
   /* Make the selected window's buffer current.  */
diff --git a/src/xfont.c b/src/xfont.c
index ce32c7a2188..fdadb05500a 100644
--- a/src/xfont.c
+++ b/src/xfont.c
@@ -238,7 +238,7 @@ xfont_chars_supported (Lisp_Object chars, XFontStruct 
*xfont,
 
 static Lisp_Object xfont_scripts_cache;
 
-/* Re-usable vector to store characteristic font properties.   */
+/* Reusable vector to store characteristic font properties.   */
 static Lisp_Object xfont_scratch_props;
 
 /* Return a list of scripts supported by the font of FONTNAME whose
diff --git a/src/xterm.c b/src/xterm.c
index 6f335ea11da..2dd86e77631 100644
--- a/src/xterm.c
+++ b/src/xterm.c
@@ -12229,7 +12229,7 @@ x_dnd_process_quit (struct frame *f, Time timestamp)
 /* This function is defined far away from the rest of the XDND code so
    it can utilize `x_any_window_to_frame'.  */
 
-/* Implementors beware!  On most other platforms (where drag-and-drop
+/* Implementers beware!  On most other platforms (where drag-and-drop
    data is not provided via selections, but some kind of serialization
    mechanism), it is usually much easier to implement a suitable
    primitive instead of copying the C code here, and then to build
diff --git a/test/lisp/international/mule-tests.el 
b/test/lisp/international/mule-tests.el
index 4dc099a18af..c973955e4ce 100644
--- a/test/lisp/international/mule-tests.el
+++ b/test/lisp/international/mule-tests.el
@@ -49,7 +49,7 @@
                        (kbd "C-x RET c u t f - 8 RET C-u C-u c a b RET")
                      (read-string "prompt:"))))))
 
-;;Bug#65997, ensure that old-names haven't overriden new names.
+;;Bug#65997, ensure that old-names haven't overridden new names.
 (ert-deftest mule-cmds-tests--ucs-names-old-name-override ()
   (let (code-points)
     (dotimes (u (1+ (max-char 'ucs)))
diff --git a/test/lisp/progmodes/perl-mode-tests.el 
b/test/lisp/progmodes/perl-mode-tests.el
index 3757ac25547..3b22c5d8750 100644
--- a/test/lisp/progmodes/perl-mode-tests.el
+++ b/test/lisp/progmodes/perl-mode-tests.el
@@ -28,7 +28,7 @@
     (font-lock-ensure (point-min) (point-max))
     (should (equal (get-text-property 4 'face) 
'font-lock-variable-name-face))))
 
-;;;; Re-use cperl-mode tests
+;;;; Reuse cperl-mode tests
 
 (defvar cperl-test-mode)
 (setq cperl-test-mode #'perl-mode)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/org/org-persist.el b/lisp/org/org-persist.el
index 01078f4596d..dc9fe3a7103 100644
--- a/lisp/org/org-persist.el
+++ b/lisp/org/org-persist.el
@@ -111,7 +111,7 @@
 ;;
 ;; Each collection is represented as a plist containing the following
 ;; properties:
 ;; - `:container'   : list of data continers to be stored in single
 ;;                    file;
 ;; - `:persist-file': data file name;
 ;; - `:associated'  : list of associated objects;
@@ -253,7 +253,7 @@ The index is a list of plists.  Each plist contains 
information about
 persistent data storage.  Each plist contains the following
 properties:
 
-  - `:container'  : list of data continers to be stored in single file
+  - `:container'  : list of data containers to be stored in single file
   - `:persist-file': data file name
   - `:associated'  : list of associated objects
   - `:last-access' : last date when the container has been read
@@ -111,7 +111,7 @@
 ;; Each collection is represented as a plist containing the following
 ;; properties:
-;; - `:container'   : list of data continers to be stored in single
+;; - `:container'   : list of data containers to be stored in single
 ;;                    file;
 ;; - `:persist-file': data file name;